@@ -1,47 +1,47 @@
 ###############################################################################
 #                                                                             #
-#    Copyright  2012-2013 -- LIRMM/UM2                                       #
+#    Copyright © 2012-2018 -- LIRMM/UM                                        #
 #                            (Laboratoire d'Informatique, de Robotique et de  #
-#                             Microlectronique de Montpellier /              #
-#                             Universit de Montpellier 2)                    #
+#                             Microélectronique de Montpellier /              #
+#                             Université de Montpellier)                      #
 #                             IRB/INSERM                                      #
-#                            (Institut de Recherche en Biothrapie /          #
-#                             Institut National de la Sant et de la          #
-#                             Recherche Mdicale)                             #
+#                            (Institut de Recherche en Biothérapie /          #
+#                             Institut National de la Santé et de la          #
+#                             Recherche Médicale)                             #
 #                                                                             #
 #  Auteurs/Authors: Alban MANCHERON  <alban.mancheron@lirmm.fr>               #
 #                   Nicolas PHILIPPE <nicolas.philippe@inserm.fr>             #
 #                                                                             #
 #  -------------------------------------------------------------------------  #
 #                                                                             #
-#  Ce fichier  fait partie  du Pipeline  de traitement  de donnes NGS de la  #
-#  plateforme ATGC lablise par le GiS IBiSA.                                #
+#  Ce fichier  fait partie  du Pipeline  de traitement  de données NGS de la  #
+#  plateforme ATGC labélisée par le GiS IBiSA.                                #
 #                                                                             #
-#  Ce logiciel est rgi  par la licence CeCILL  soumise au droit franais et  #
+#  Ce logiciel est régi  par la licence CeCILL  soumise au droit français et  #
 #  respectant les principes  de diffusion des logiciels libres.  Vous pouvez  #
 #  utiliser, modifier et/ou redistribuer ce programme sous les conditions de  #
-#  la licence CeCILL  telle que diffuse par le CEA,  le CNRS et l'INRIA sur  #
+#  la licence CeCILL  telle que diffusée par le CEA,  le CNRS et l'INRIA sur  #
 #  le site "http://www.cecill.info".                                          #
 #                                                                             #
-#  En contrepartie de l'accessibilit au code source et des droits de copie,  #
-#  de modification et de redistribution accords par cette licence, il n'est  #
-#  offert aux utilisateurs qu'une garantie limite.  Pour les mmes raisons,  #
-#  seule une responsabilit  restreinte pse  sur l'auteur du programme,  le  #
-#  titulaire des droits patrimoniaux et les concdants successifs.            #
+#  En contrepartie de l'accessibilité au code source et des droits de copie,  #
+#  de modification et de redistribution accordés par cette licence, il n'est  #
+#  offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,  #
+#  seule une responsabilité  restreinte pèse  sur l'auteur du programme,  le  #
+#  titulaire des droits patrimoniaux et les concédants successifs.            #
 #                                                                             #
-#    cet gard  l'attention de  l'utilisateur est  attire sur  les risques  #
-#  associs  au chargement,   l'utilisation,   la modification  et/ou au  #
-#  dveloppement  et la reproduction du  logiciel par  l'utilisateur tant  #
-#  donn  sa spcificit  de logiciel libre,  qui peut le rendre  complexe   #
-#  manipuler et qui le rserve donc des dveloppeurs et des professionnels  #
-#  avertis  possdant  des  connaissances  informatiques  approfondies.  Les  #
-#  utilisateurs  sont donc  invits   charger  et  tester  l'adquation du  #
-#  logiciel  leurs besoins  dans des conditions  permettant  d'assurer  la  #
-#  scurit de leurs systmes et ou de leurs donnes et,  plus gnralement,  #
-#  l'utiliser et l'exploiter dans les mmes conditions de scurit.         #
+#  À  cet égard  l'attention de  l'utilisateur est  attirée sur  les risques  #
+#  associés  au chargement,  à  l'utilisation,  à  la modification  et/ou au  #
+#  développement  et à la reproduction du  logiciel par  l'utilisateur étant  #
+#  donné  sa spécificité  de logiciel libre,  qui peut le rendre  complexe à  #
+#  manipuler et qui le réserve donc à des développeurs et des professionnels  #
+#  avertis  possédant  des  connaissances  informatiques  approfondies.  Les  #
+#  utilisateurs  sont donc  invités  à  charger  et  tester  l'adéquation du  #
+#  logiciel  à leurs besoins  dans des conditions  permettant  d'assurer  la  #
+#  sécurité de leurs systêmes et ou de leurs données et,  plus généralement,  #
+#  à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.         #
 #                                                                             #
-#  Le fait  que vous puissiez accder  cet en-tte signifie  que vous avez  #
-#  pris connaissance  de la licence CeCILL,  et que vous en avez accept les  #
+#  Le fait  que vous puissiez accéder  à cet en-tête signifie  que vous avez  #
+#  pris connaissance  de la licence CeCILL,  et que vous en avez accepté les  #
 #  termes.                                                                    #
 #                                                                             #
 #  -------------------------------------------------------------------------  #
@@ -77,11 +77,14 @@
 #                                                                             #
 ###############################################################################
 #
-# $Id: FileManager.pm,v 1.6 2013/11/07 10:19:25 doccy Exp $
+# $Id: FileManager.pm,v 1.7 2018/03/19 13:16:31 doccy Exp $
 #
 ###############################################################################
 #
 # $Log: FileManager.pm,v $
+# Revision 1.7  2018/03/19 13:16:31  doccy
+# BugFix: module file was encoded with ISO-8859-1. Switching to UT-8.
+#
 # Revision 1.6  2013/11/07 10:19:25  doccy
 # Renaming the module.
 #
@@ -89,7 +92,7 @@
 # Update Copyright informations
 #
 # Revision 1.4  2013/05/22 10:42:43  doccy
-# Add CéCILL Copyright Notice
+# Add CÃ©CILL Copyright Notice
 #
 # Revision 1.3  2013/05/22 08:11:25  doccy
 # Fix POD examples.
@@ -124,7 +127,7 @@ require Exporter;
 
 our @ISA = qw(Exporter);
 
-our $VERSION = (qw$Revision: 1.6 $)[-1];
+our $VERSION = (qw$Revision: 1.7 $)[-1];
 
 ###########################
 # Plain Old Documentation #
@@ -698,22 +701,22 @@ Nicolas PHILIPPE E<lt>L<nicolas.philippe@inserm.fr|mailto:nicolas.philippe@inser
 
 Copyright (C) 2012-2013 -- LIRMM/UM2
                            (Laboratoire d'Informatique, de Robotique et de
-                            Microlectronique de Montpellier /
-                            Universit de Montpellier 2)
+                            Microélectronique de Montpellier /
+                            Université de Montpellier 2)
                            IRB/INSERM
-                           (Institut de Recherche en Biothrapie /
-                            Institut National de la Sant et de la
-                            Recherche Mdicale)
+                           (Institut de Recherche en Biothérapie /
+                            Institut National de la Santé et de la
+                            Recherche Médicale)
 
 =head2 FRENCH
 
-Ce fichier  fait partie  du Pipeline  de traitement  de donnes NGS de la
-plateforme ATGC lablise par le GiS IBiSA.
+Ce fichier  fait partie  du Pipeline  de traitement  de données NGS de la
+plateforme ATGC labélisée par le GiS IBiSA.
 
-Ce logiciel est rgi  par la licence CeCILL  soumise au droit franais et
+Ce logiciel est régi  par la licence CeCILL  soumise au droit français et
 respectant les principes  de diffusion des logiciels libres.  Vous pouvez
 utiliser, modifier et/ou redistribuer ce programme sous les conditions de
-la licence CeCILL  telle que diffuse par le CEA,  le CNRS et l'INRIA sur
+la licence CeCILL  telle que diffusée par le CEA,  le CNRS et l'INRIA sur
 le site "http://www.cecill.info".
 
 =head2 ENGLISH
